/**
 * Copyright (C) 2015 - 2018 Kosmos contact@kosmos.fr
 *
 * Projet: blog
 * Version: 1.07.00
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package fr.kosmos.selenium.blog;

import java.lang.reflect.InvocationTargetException;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.apache.commons.beanutils.BeanUtils;
import org.testng.annotations.Test;

import fr.kosmos.selenium.annotation.Exigence;
import fr.kosmos.selenium.bean.BilletDeBlogBean;
import fr.kosmos.selenium.core.KSupTestCase;
import fr.kosmos.selenium.service.fiche.ServiceBilletDeBlog;
import fr.kosmos.selenium.utils.EnumExtension;
import fr.kosmos.selenium.utils.RoleTest;

/**
 * Created on 27/03/18.
 *
 * @author samuel.dubernet
 */
public class ITBilletDeBlogTestCase extends KSupTestCase {

    private ServiceBilletDeBlog serviceBilletDeBlog;

    private final String libelleAffichableArchiveRestaureSuppr = "Titre billet de blog brouillon";

    private final EnumExtension extBiBl = EnumExtension.BILLET_DE_BLOG;
    private final EnumExtension extBlog = EnumExtension.BLOG;

    /**
     * {@inheritDoc}
     */
    @Override
    public void initScreen() {
        serviceBilletDeBlog = new ServiceBilletDeBlog(this);
    }

    private BilletDeBlogBean defaultBean() {
        final BilletDeBlogBean billetDeBlogBean = new BilletDeBlogBean();
        final DateFormat dateFormat = new SimpleDateFormat("dd MMMM yyyy");
        final Date date = new Date();
        final String displayDateFormat = dateFormat.format(date);
        final String[] valPathRubrique = { "Site DATA", "Version française", "Navigation", "Modules et extensions", "Blogs" };
        final String nomBlog = "Matthieu Deforge";
        final List<String> tags = new ArrayList<>();
        tags.add("TAG1");

        //Fonction billet de blog
        billetDeBlogBean.setAuteur("Administrateur K-Sup");
        billetDeBlogBean.setDateCreation(displayDateFormat.toString());
        billetDeBlogBean.setRubriquePath(valPathRubrique);
        billetDeBlogBean.setRubrique(String.format("Blog [%s]", nomBlog));
        billetDeBlogBean.setTitre("Titre du billet de blog");
        billetDeBlogBean.setLibelleAffichable(billetDeBlogBean.getTitre());
        billetDeBlogBean.setChapeau("Ceci est un chapeau : Lorem ipsum dolor sit amet, consectetur cras amet.");
        billetDeBlogBean.setBillet("Ceci est un billet : Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce nec metus tristique felis massa nunc.");
        billetDeBlogBean.setTags(tags);
        billetDeBlogBean.setLienAjoutBillet("Ajouter un billet à ce blog");
        billetDeBlogBean.setEncadre("Ceci est un encadré.");
        //Fonction blog
        billetDeBlogBean.setTitreBlog(nomBlog);
        billetDeBlogBean.setAuteurBlog("Aur Bouyge");
        billetDeBlogBean.setThematiqueBlog("Administratif");
        billetDeBlogBean.setDateCreationBlog("12 mai 2016");
        billetDeBlogBean.setNbreArticlesBlog("0");
        billetDeBlogBean.setNbreCommentairesBlog("0");
        billetDeBlogBean.setDescriptionBlog("Opération, Élection, Présidence");
        billetDeBlogBean.setDateModificationBlog(displayDateFormat);

        return billetDeBlogBean;
    }

    private BilletDeBlogBean modifiedBean() {
        final BilletDeBlogBean billetDeBlogBean = new BilletDeBlogBean();
        final List<String> tags = new ArrayList<>();
        tags.add("TAG2");

        billetDeBlogBean.setTitre("Titre modifié du billet de blog");
        billetDeBlogBean.setLibelleAffichable(billetDeBlogBean.getTitre());
        billetDeBlogBean.setChapeau("Ceci est un chapeau modifié : Plus petit.");
        billetDeBlogBean.setBillet("Ceci est un billet modifié : Beaucoup plus petit.");
        billetDeBlogBean.setTags(tags);

        billetDeBlogBean.setNbreArticlesBlog("1");

        return billetDeBlogBean;
    }

    @Test
    @Exigence(afinDe = "Vérifier que tous les champs de la fiche billet de blog apparaîssent en front office",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Publier une fiche ayant tous ses champs renseignés",
    ticketExigence = "KRTO-654",
    ticketTest = "KRTO-1187")
    public void testCreationBilletDeBlog() {
        final BilletDeBlogBean billetDeBlogBean = defaultBean();
        billetDeBlogBean.setVariablePrevisualisation(true);
        serviceBilletDeBlog.createContentBO(extBiBl, billetDeBlogBean);
    }

    @Test(dependsOnMethods = "testCreationBilletDeBlog")
    @Exigence(afinDe = "Vérifier que tous les champs de la fiche billet de blog apparaîssent en front office",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Visualiser ma fiche publié ayant tous ses champs renseignés",
    ticketExigence = "KRTO-657",
    ticketTest = "KRTO-1188")
    public void testVisualisationBilletDeBlog() {
        final BilletDeBlogBean billetDeBlogBean = defaultBean();
        billetDeBlogBean.setVariablePrevisualisation(false);
        billetDeBlogBean.setNbreArticlesBlog("1");
        serviceBilletDeBlog.previewContentBO(extBiBl, billetDeBlogBean);
    }

    @Test(dependsOnMethods = "testVisualisationBilletDeBlog")
    @Exigence(afinDe = "Vérifier que tous les champs de la fiche billet de blog modifier apparaîssent en front office et soit bien mis à jour",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Modifier une fiche ayant tous ses champs renseignés",
    ticketExigence = "KRTO-662",
    ticketTest = "KRTO-1190")
    public void testModificationBilletDeBlog() {
        final BilletDeBlogBean billetDeBlogBean = defaultBean();
        final BilletDeBlogBean billetDeBlogBeanModified = modifiedBean();
        billetDeBlogBean.setVariablePrevisualisation(false);
        serviceBilletDeBlog.updateContentBO(extBiBl, billetDeBlogBean, billetDeBlogBeanModified);
    }

    @Test(dependsOnMethods = "testModificationBilletDeBlog")
    @Exigence(afinDe = "Enregistrer une fiche billet de blog en brouillon",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Rééditer la fiche",
    ticketExigence = "KRTO-1192",
    ticketTest = "KRTO-1193")
    public void testEnregBrouillonBilletDeBlog() {
        final BilletDeBlogBean billetDeBlogBean = new BilletDeBlogBean();
        billetDeBlogBean.setTitre(libelleAffichableArchiveRestaureSuppr);
        billetDeBlogBean.setLibelleAffichable(billetDeBlogBean.getTitre());
        serviceBilletDeBlog.draftSaveContentBO(extBiBl, billetDeBlogBean);
    }

    @Test(dependsOnMethods = "testEnregBrouillonBilletDeBlog")
    @Exigence(afinDe = "Archiver une fiche billet de blog depuis cette même fiche",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Archiver la fiche",
    ticketExigence = "KRTO-1194",
    ticketTest = "KRTO-1195")
    public void testArchivageBilletDeBlog() {
        serviceBilletDeBlog.archiveContentBO(extBiBl, libelleAffichableArchiveRestaureSuppr);
    }

    @Test(dependsOnMethods = "testArchivageBilletDeBlog")
    @Exigence(afinDe = "Restaurer une fiche billet de blog depuis cette même fiche",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Restaurer une fiche archivé",
    ticketExigence = "KRTO-1196",
    ticketTest = "KRTO-1197")
    public void testRestaurationBilletDeBlog() {
        serviceBilletDeBlog.restoreContentBO(extBiBl, libelleAffichableArchiveRestaureSuppr);
    }

    @Test(dependsOnMethods = "testRestaurationBilletDeBlog")
    @Exigence(afinDe = "Supprimer une fiche billet de blog depuis cette même fiche",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Supprimer une fiche",
    ticketExigence = "KRTO-660",
    ticketTest = "KRTO-1191")
    public void testSuppressionBilletDeBlog() {
        serviceBilletDeBlog.deleteContentBO(extBiBl, libelleAffichableArchiveRestaureSuppr);
    }

    @Test(dependsOnMethods = "testSuppressionBilletDeBlog")
    @Exigence(afinDe = "Créer une fiche billet de blog depuis le front office d'un blog",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Créer une ficher depuis le FO",
    ticketExigence = "KRTO-636",
    ticketTest = "KRTO-1198")
    public void testCreationBilletDeBlogFO() throws IllegalAccessException, InvocationTargetException {
        final BilletDeBlogBean billetDeBlogBean = defaultBean();
        final List<String> tags = new ArrayList<>();
        tags.add("TAG");

        billetDeBlogBean.setTitre(billetDeBlogBean.getTitre() + " en FO");
        billetDeBlogBean.setLibelleAffichable(billetDeBlogBean.getTitre());
        billetDeBlogBean.setBillet("Ceci est un billet en FO : Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce nec metus tristique felis massa nunc.");
        billetDeBlogBean.setChapeau("Ceci est un chapeau en FO : Lorem ipsum dolor sit amet, consectetur cras amet.");
        billetDeBlogBean.setTags(tags);
        billetDeBlogBean.setNbreArticlesBlog("2");
        billetDeBlogBean.setEncadre(null);

        final BilletDeBlogBean premierBilletBean = defaultBean();
        final BilletDeBlogBean billetDeBlogBeanModified = modifiedBean();

        BeanUtils.copyProperties(premierBilletBean, billetDeBlogBeanModified);

        serviceMenuBO.navigateToContenu(extBlog);
        serviceBilletDeBlog.viewContentDatagrid(billetDeBlogBean.getTitreBlog());
        serviceBilletDeBlog.ajouteBilletDeBlog();
        serviceBilletDeBlog.fillContentFO(billetDeBlogBean);
        serviceBilletDeBlog.valideCreationBilletDeBlogFO();
        serviceBilletDeBlog.controlCreationReussiFO();
        serviceBilletDeBlog.controlFrontBlogApresConfirmation(billetDeBlogBean, premierBilletBean);
        serviceBilletDeBlog.clickBilletDeBlogFO();
        serviceBilletDeBlog.controlFrontBilletDeBlogApresConfirmation(billetDeBlogBean);
    }
}
