/**
 * Copyright (C) 2015 - 2018 Kosmos contact@kosmos.fr
 *
 * Projet: blog
 * Version: 1.07.00
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package fr.kosmos.selenium.blog;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.testng.annotations.Test;

import fr.kosmos.selenium.annotation.Exigence;
import fr.kosmos.selenium.bean.BlogBean;
import fr.kosmos.selenium.bean.LibelleBean;
import fr.kosmos.selenium.core.KSupTestCase;
import fr.kosmos.selenium.service.fiche.ServiceBlog;
import fr.kosmos.selenium.utils.EnumExtension;
import fr.kosmos.selenium.utils.RoleTest;

/**
 * Created on 23/03/18.
 *
 * @author samuel.dubernet
 */
public class ITBlogTestCase extends KSupTestCase {

    private ServiceBlog serviceBlog;

    private final String libelleAffichableArchiveRestaureSuppr = "Titre blog brouillon";

    private final EnumExtension extBlog = EnumExtension.BLOG;

    /**
     * {@inheritDoc}
     */
    @Override
    public void initScreen() {
        serviceBlog = new ServiceBlog(this);
    }

    private BlogBean defaultBean() {
        final DateFormat dateFormat = new SimpleDateFormat("dd MMMM yyyy");
        final Date date = new Date();
        final String displayDateFormat = dateFormat.format(date);
        final List<String> listThematique = new ArrayList<>();
        listThematique.add("Emploi");

        final LibelleBean libelleBeanThematique = new LibelleBean("03", "Emploi", StringUtils.EMPTY);
        final BlogBean blogBean = new BlogBean();
        blogBean.setListThematique(listThematique);

        blogBean.setRubrique("Les fiches et leurs listes");
        blogBean.setStructure("Structures pour l'intégration et jeux de données");
        blogBean.setTitre("Ceci est le titre du blog.");
        blogBean.setLibelleAffichable(blogBean.getTitre());
        blogBean.setDescription(
            "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam mattis ut libero at fringilla. Pellentesque vel nulla nisl. Vestibulum eget quam justo. Phasellus nunc purus, aliquet a metus nec, scelerisque consequat urna. Nullam tristique ipsum sed.");
        blogBean.setThematique(libelleBeanThematique);
        blogBean.setArchivage("ARCHIVAGE0");
        blogBean.setBandeau("686");
        blogBean.setUrlBackground(this.getMainHost() + "/medias/photo/northwind-by-aenami-da1skxc_1477035912268-jpg");
        blogBean.setAuteur("Administrateur K-Sup");
        blogBean.setDateCreation(displayDateFormat);
        blogBean.setArticle("0");
        blogBean.setCommentaire("0");

        blogBean.setEncadre("Je suis un encadre.");
        return blogBean;
    }

    private BlogBean modifiedBean() {
        final List<String> listThematique = new ArrayList<>();
        listThematique.add("Emploi");
        listThematique.add("Administratif");

        final LibelleBean libelleBeanThematique = new LibelleBean("01", "Administratif", StringUtils.EMPTY);
        final BlogBean blogBean = new BlogBean();
        blogBean.setListThematique(listThematique);

        blogBean.setTitre("Ceci est le titre modifié du blog.");
        blogBean.setLibelleAffichable(blogBean.getTitre());
        blogBean.setDescription("Une description un peu plus courte.");
        blogBean.setThematique(libelleBeanThematique);
        blogBean.setArchivage("ARCHIVAGE1");
        blogBean.setBandeau("631");
        blogBean.setUrlBackground(this.getMainHost() + "/medias/photo/homme-reduit_1463066146605-jpg");
        blogBean.setEncadre("Je suis un encadre modifié.");
        return blogBean;
    }

    @Test
    @Exigence(afinDe = "Vérifier que tous les champs de la fiche apparaîssent en front office",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Publier une fiche ayant tous ses champs renseignés",
    ticketExigence = "KRTO-621",
    ticketTest = "KRTO-1157")
    public void testCreationBlog() {
        final BlogBean blogBean = defaultBean();
        blogBean.setVariablePrevisualisation(true);
        serviceBlog.createContentBO(extBlog, blogBean);
    }

    @Test(dependsOnMethods = "testCreationBlog")
    @Exigence(afinDe = "Vérifier que tous les champs de la fiche modifier apparaîssent en front office et soit bien mis à jour",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Modifier une fiche ayant tous ses champs renseignés",
    ticketExigence = "KRTO-629",
    ticketTest = "KRTO-1175")
    public void testModificationBlog() {
        final BlogBean blogBean = defaultBean();
        final BlogBean blogBeanModified = modifiedBean();
        blogBeanModified.setVariablePrevisualisation(false);
        serviceBlog.updateContentBO(extBlog, blogBean, blogBeanModified);
    }

    @Test(dependsOnMethods = "testModificationBlog")
    @Exigence(afinDe = "Vérifier que tous les champs de la fiche apparaîssent en front office",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Visualiser ma fiche ayant tous ses champs renseignés",
    ticketExigence = "KRTO-603",
    ticketTest = "KRTO-1176")
    public void testVisualisationBlog() {
        final BlogBean blogBean = modifiedBean();
        blogBean.setVariablePrevisualisation(false);
        serviceBlog.previewContentBO(extBlog, blogBean);
    }

    @Test
    @Exigence(afinDe = "Enregistrer une fiche en brouillon", enTantQue = RoleTest.ADMIN, jeVeux = "Rééditer la fiche", ticketExigence = "KRTO-623", ticketTest = "KRTO-1177")
    public void testEnregBrouillonBlog() {
        final BlogBean blogBean = new BlogBean();
        blogBean.setRubrique("Les fiches et leurs listes");
        blogBean.setTitre(libelleAffichableArchiveRestaureSuppr);
        blogBean.setLibelleAffichable(blogBean.getTitre());
        serviceBlog.draftSaveContentBO(extBlog, blogBean);
    }

    @Test(dependsOnMethods = "testEnregBrouillonBlog")
    @Exigence(afinDe = "Archiver une fiche blog depuis cette même fiche",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Archiver la fiche",
    ticketExigence = "KRTO-619",
    ticketTest = "KRTO-1178")
    public void testArchivageBlog() {
        serviceBlog.archiveContentBO(extBlog, libelleAffichableArchiveRestaureSuppr);
    }

    @Test(dependsOnMethods = "testArchivageBlog")
    @Exigence(afinDe = "Restaurer une fiche blog depuis cette même fiche",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Restaurer une fiche archivé",
    ticketExigence = "KRTO-625",
    ticketTest = "KRTO-1186")
    public void testRestaurationBlog() {
        serviceBlog.restoreContentBO(extBlog, libelleAffichableArchiveRestaureSuppr);
    }

    @Test(dependsOnMethods = "testRestaurationBlog")
    @Exigence(afinDe = "Supprimer une fiche blog depuis cette même fiche",
    enTantQue = RoleTest.ADMIN,
    jeVeux = "Supprimer une fiche",
    ticketExigence = "KRTO-627",
    ticketTest = "KRTO-1185")
    public void testSuppressionBlog() {
        serviceBlog.deleteContentBO(extBlog, libelleAffichableArchiveRestaureSuppr);
    }
}
